#line 2 "llsphinxql.c"

#line 4 "llsphinxql.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin ,yyscanner )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void yyrestart (FILE *input_file ,yyscan_t yyscanner );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer ,yyscan_t yyscanner );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size ,yyscan_t yyscanner );
void yy_delete_buffer (YY_BUFFER_STATE b ,yyscan_t yyscanner );
void yy_flush_buffer (YY_BUFFER_STATE b ,yyscan_t yyscanner );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer ,yyscan_t yyscanner );
void yypop_buffer_state (yyscan_t yyscanner );

static void yyensure_buffer_stack (yyscan_t yyscanner );
static void yy_load_buffer_state (yyscan_t yyscanner );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file ,yyscan_t yyscanner );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER ,yyscanner)

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size ,yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str ,yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,int len ,yyscan_t yyscanner );

void *yyalloc (yy_size_t ,yyscan_t yyscanner );
void *yyrealloc (void *,yy_size_t ,yyscan_t yyscanner );
void yyfree (void * ,yyscan_t yyscanner );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define yywrap(n) 1
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state (yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  ,yyscan_t yyscanner);
static int yy_get_next_buffer (yyscan_t yyscanner );
static void yy_fatal_error (yyconst char msg[] ,yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;

#define YY_NUM_RULES 112
#define YY_END_OF_BUFFER 113
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[447] =
    {   0,
        0,    0,    0,    0,  113,  111,  110,  110,  111,  111,
      111,  111,  100,  111,  111,  111,  111,  104,  104,  104,
      104,  104,  104,  104,  104,  104,  104,  104,  104,  104,
      104,  104,  104,  104,  104,  104,  111,    2,  112,    2,
      110,   91,    0,   96,    0,   98,    1,   97,  100,  105,
      105,   95,   93,   92,   94,    0,  106,  106,  106,  106,
      104,  104,  104,  104,    6,  104,  104,  104,  104,   13,
      104,  104,  104,  104,  104,  104,  104,  104,  104,  104,
      104,  104,  104,   36,   37,  104,  104,  104,  104,  104,
      104,  104,  104,  104,  104,  104,   56,  104,  104,  104,

      104,  104,  104,  104,  104,  104,  104,  104,  104,   79,
      104,  104,  104,  104,  104,  104,  104,  104,    0,    0,
        3,    0,    0,   97,    0,    0,   99,  107,  106,  106,
      101,  106,  104,    5,    7,  104,    9,  104,  104,  104,
      104,  104,  104,  104,  104,  104,  104,  104,  104,   25,
      104,  104,  104,  104,  104,  104,  104,  104,  104,  104,
       40,  104,  104,  104,  104,  104,   47,  104,   49,   50,
      104,   52,  104,  104,  104,  104,  104,  104,  104,  104,
      104,  104,  104,  104,  104,  104,  104,   70,  104,  104,
      104,  104,   77,  104,  104,  104,  104,  104,  104,  104,

      104,  104,  104,  104,    0,  109,    0,    0,   98,    0,
       97,   99,  107,  106,  106,  104,  104,  104,  104,  104,
       14,  104,  104,  104,  104,  104,  104,   22,  104,   26,
      104,  104,  104,   30,  104,  104,  104,  104,  104,   41,
      104,  104,   44,  104,  104,   48,  104,   53,  104,  104,
       58,  104,  104,   61,   62,  104,  104,  104,  104,  104,
      104,  104,  104,   72,  104,  104,  104,  104,  104,  104,
       81,  104,  104,  104,  104,  104,  104,  104,  104,  104,
      108,  106,  106,    4,  104,   10,  104,  104,  104,  104,
      104,   19,  104,  104,  104,  104,   27,   28,   29,  104,

      104,   33,   38,  104,  104,   43,   45,   46,   51,  104,
      104,   57,  104,  104,  104,  104,  104,  104,  104,  104,
      104,  104,  104,   74,  104,  104,  104,  104,  104,  104,
      104,  104,  104,  104,  104,   89,  104,  103,  106,    8,
      104,   12,  104,  104,   17,   20,   21,  104,  104,  104,
       32,  104,  104,   39,  104,  104,   54,  104,  104,  104,
      104,  104,  104,  104,   68,  104,  104,   73,   75,   76,
       78,  104,  104,  104,   84,   85,  104,  104,   88,   90,
      102,   11,  104,  104,  104,  104,  104,  104,   34,  104,
      104,  104,   59,  104,  104,   64,   65,  104,   67,  104,

       71,  104,  104,  104,  104,  104,  104,  104,  104,   23,
       24,   31,  104,  104,   55,   60,  104,   66,  104,  104,
       82,  104,  104,   87,   15,   16,   18,  104,   42,  104,
      104,  104,  104,   86,  104,   63,  104,  104,  104,  104,
      104,   80,   83,   35,   69,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    4,    1,    1,    1,    1,    1,    5,    1,
        1,    6,    7,    1,    8,    9,   10,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   12,    1,   13,
       14,   15,    1,   16,   17,   18,   19,   20,   21,   22,
       23,   24,   25,   26,   27,   28,   29,   30,   31,   32,
       26,   33,   34,   35,   36,   37,   38,   39,   40,   41,
        1,   42,    1,    1,   43,   44,   45,   46,   47,   48,

       49,   50,   51,   52,   53,   26,   54,   55,   56,   57,
       58,   59,   26,   60,   61,   62,   63,   64,   65,   66,
       67,   68,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[69] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    1,
        2,    1,    1,    1,    1,    3,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    1,    4,    5,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
        4,    4,    4,    4,    4,    4,    4,    4
    } ;

static yyconst flex_int16_t yy_base[458] =
    {   0,
        0,    0,   66,   67, 1268, 1269,   72,   74, 1253,   66,
     1255, 1259,   69, 1250,   67, 1249,   67,  124,   70,   76,
       78, 1253,  107,   89,  121,  104,  159,  156,  139,  174,
      201,  255,  180,  194,  211,  248,   59, 1269, 1269, 1251,
       86, 1269,   97, 1269,  103,  145, 1269,  184,  226, 1251,
      234, 1269, 1269, 1269, 1269,    0,    0,   84,  126,  142,
        0, 1250,  200,  207,  235,  243,  251,  257,  258, 1249,
      151,  253,  259,  262,  297,  287,  268,  168,  301,  285,
      303,  311,  314, 1248,  319,  318,  221,  341,  326,  294,
      325,  327,  337,  348,  335,  364,  365,  362,  331,  375,

      377,  368,  389,  410,  369,  378,  407,  392,  411, 1247,
      424,  406,  382,  428,  425,  437,  442,  419, 1211,  429,
     1269,  413,  467,  455,  485, 1243,   85,    0,    0,  423,
        0,  236,  438, 1244, 1243,  480, 1242,  455,  441,  473,
      475,  485,  491,  492,  490,  493,  502,  496,  498, 1241,
      500,  503,  505,  507,  515,  508,  531,  520,  533,  544,
      504,  530,  548,  552,  527,  557, 1240,  558, 1239, 1238,
      563, 1237,  561,  554,  565,  569,  572,  581,  582,  586,
      587,  583,  589,  601,  600,  602,  579, 1236,  609,  615,
      624,  614, 1235,  620,  611,  641,  634,  628,  616,  629,

      626,  654,  652,  642, 1199, 1269, 1198, 1230, 1229, 1228,
     1227, 1226,    0,  623,  646,  661,  669,  663,  655,  672,
     1227,  682,  686,  692,  678,  680,  691,  697,  699, 1226,
      698,  700,  709, 1224,  701,  705,  712,  702,  716, 1220,
      729,  723, 1217,  719,  734, 1214,  730, 1211,  746,  739,
     1206,  757,  756, 1193, 1192,  750,  770,  751,  774,  776,
      779,  780,  781, 1191,  784,  792,  785,  798,  796,  803,
     1190,  800,  794,  807,  809,  822,  813,  805,  823,  824,
     1269,  738,  811, 1189,  827, 1188,  832,  843,  837,  850,
      851, 1185,  852,  853,  862,  859, 1182, 1181, 1180,  866,

      867,  874, 1179,  861,  871, 1178, 1177, 1175, 1174,  873,
      879, 1172,  890,  885,  894,  881,  884,  915,  916,  895,
      899,  922,  925, 1171,  901,  888,  929,  933,  934,  935,
      938,  943,  940,  931,  946, 1170,  959,    0,  931, 1169,
      962, 1165,  960,  958,  961, 1163, 1162,  964,  966,  963,
     1156,  967,  990, 1130,  975,  988, 1065,  993,  994, 1003,
      996,  992, 1016, 1018, 1037, 1006, 1009,  997,  989,  898,
      856, 1021, 1023, 1024,  834,  761, 1027, 1029,  760,  747,
        0,  728, 1041, 1034, 1051, 1052, 1032, 1045,  725, 1038,
     1055, 1062,  596, 1061, 1080,  578,  525, 1070,  522, 1035,

      519, 1069, 1072, 1082, 1078, 1086, 1096, 1098, 1103,  408,
      402,  397, 1100, 1105,  394,  332, 1097,  329, 1101, 1107,
      321, 1099, 1124,  275,  239,  230,  222, 1129,  206, 1128,
     1127, 1110, 1133,  191, 1150,  184, 1141, 1113, 1144, 1131,
     1154,  155,  141,  117,   95, 1269, 1203, 1208, 1212, 1214,
     1217,   97,   93, 1220, 1223, 1226, 1230
    } ;

static yyconst flex_int16_t yy_def[458] =
    {   0,
      446,    1,  447,  447,  446,  446,  446,  446,  446,  448,
      446,  446,  449,  446,  446,  446,  450,  451,  451,  451,
      451,  451,  451,  451,  451,  451,  451,  451,  451,  451,
      451,  451,  451,  451,  451,  451,  452,  446,  446,  446,
      446,  446,  448,  446,  448,  446,  446,  446,  449,  449,
      449,  446,  446,  446,  446,  453,  454,  454,  454,  454,
      455,  451,  451,  451,  451,  451,  451,  451,  451,  451,
      451,  451,  451,  451,  451,  451,  451,  451,  451,  451,
      451,  451,  451,  451,  451,  451,  451,  451,  451,  451,
      451,  451,  451,  451,  451,  451,  451,  451,  451,  451,

      451,  451,  451,  451,  451,  451,  451,  451,  451,  451,
      451,  451,  451,  451,  451,  451,  451,  451,  456,  456,
      446,  448,  446,  446,  446,  446,  449,  457,  454,  454,
      454,  454,  451,  451,  451,  451,  451,  451,  451,  451,
      451,  451,  451,  451,  451,  451,  451,  451,  451,  451,
      451,  451,  451,  451,  451,  451,  451,  451,  451,  451,
      451,  451,  451,  451,  451,  451,  451,  451,  451,  451,
      451,  451,  451,  451,  451,  451,  451,  451,  451,  451,
      451,  451,  451,  451,  451,  451,  451,  451,  451,  451,
      451,  451,  451,  451,  451,  451,  451,  451,  451,  451,

      451,  451,  451,  451,  456,  446,  456,  446,  446,  446,
      446,  446,  457,  454,  454,  451,  451,  451,  451,  451,
      451,  451,  451,  451,  451,  451,  451,  451,  451,  451,
      451,  451,  451,  451,  451,  451,  451,  451,  451,  451,
      451,  451,  451,  451,  451,  451,  451,  451,  451,  451,
      451,  451,  451,  451,  451,  451,  451,  451,  451,  451,
      451,  451,  451,  451,  451,  451,  451,  451,  451,  451,
      451,  451,  451,  451,  451,  451,  451,  451,  451,  451,
      446,  454,  454,  451,  451,  451,  451,  451,  451,  451,
      451,  451,  451,  451,  451,  451,  451,  451,  451,  451,

      451,  451,  451,  451,  451,  451,  451,  451,  451,  451,
      451,  451,  451,  451,  451,  451,  451,  451,  451,  451,
      451,  451,  451,  451,  451,  451,  451,  451,  451,  451,
      451,  451,  451,  451,  451,  451,  451,  454,  454,  451,
      451,  451,  451,  451,  451,  451,  451,  451,  451,  451,
      451,  451,  451,  451,  451,  451,  451,  451,  451,  451,
      451,  451,  451,  451,  451,  451,  451,  451,  451,  451,
      451,  451,  451,  451,  451,  451,  451,  451,  451,  451,
      454,  451,  451,  451,  451,  451,  451,  451,  451,  451,
      451,  451,  451,  451,  451,  451,  451,  451,  451,  451,

      451,  451,  451,  451,  451,  451,  451,  451,  451,  451,
      451,  451,  451,  451,  451,  451,  451,  451,  451,  451,
      451,  451,  451,  451,  451,  451,  451,  451,  451,  451,
      451,  451,  451,  451,  451,  451,  451,  451,  451,  451,
      451,  451,  451,  451,  451,    0,  446,  446,  446,  446,
      446,  446,  446,  446,  446,  446,  446
    } ;

static yyconst flex_int16_t yy_nxt[1338] =
    {   0,
        6,    7,    8,    9,   10,    6,    6,    6,   11,   12,
       13,   14,   15,    6,   16,   17,   18,   19,   20,   21,
       22,   23,   24,   22,   25,   22,   22,   26,   27,   28,
       29,   30,   31,   32,   33,   34,   35,   36,   22,   22,
       22,    6,   22,   37,   18,   19,   20,   21,   22,   23,
       24,   22,   25,   22,   26,   27,   28,   29,   30,   31,
       32,   33,   34,   35,   36,   22,   22,   22,   39,   39,
       44,   40,   40,   41,   41,   41,   41,   48,   61,   49,
       53,   54,   56,  120,   61,   58,   61,   41,   41,   51,
       68,   59,   71,  446,   69,  127,  128,   61,   75,   72,

      119,   44,   76,   61,   60,  446,   73,   45,   74,   70,
       77,  120,   61,   58,  130,   61,   82,   51,   68,   59,
       71,   83,   69,   78,   87,   61,   75,   72,   88,   61,
       76,   60,   61,   73,   79,   74,   70,   77,   45,   80,
       84,  130,   81,   82,  122,  131,   63,   61,   83,   61,
       85,   78,   87,   64,   86,   46,   88,   65,   66,   61,
       67,   79,  132,   61,   61,  123,   80,   61,   84,   81,
       96,   97,   93,  131,   63,   89,   61,   85,  141,   90,
       64,   86,   61,   91,   65,   66,   94,   67,   61,   92,
      132,   95,   61,  123,  124,  152,  109,   96,   97,   61,

       93,   98,   61,   89,  125,  141,   99,   90,   61,   61,
      110,   91,  111,   94,   61,   61,   92,  100,   95,   61,
      133,  101,  152,  112,  109,  113,  134,  114,   98,   61,
       61,  102,  125,   99,   48,  103,   49,  110,   61,  111,
      126,  126,  446,   61,  127,  100,   51,   61,  133,  101,
      112,   61,  113,  135,  134,  114,   61,  163,  102,   61,
      215,   61,  103,   61,  115,   61,   61,   61,  116,  142,
       61,  117,  118,  137,   51,  104,   61,  136,  105,  138,
      140,  135,  146,   61,  163,  106,  143,  144,  215,  107,
      108,  139,  115,   61,  145,   61,  116,  142,  151,  117,

      118,  137,   61,  104,  136,   61,  105,  138,  140,   61,
      146,   61,  106,  143,  144,  155,  107,  108,  139,   61,
      149,  145,   61,  150,  147,  151,   61,   61,  168,   61,
      148,  153,  156,   61,   61,   61,  154,   61,  159,   61,
       61,  157,  155,   61,  158,   61,  170,  149,  162,   61,
      150,  147,  160,  161,  169,  168,   61,  148,  153,  156,
      166,  177,  173,  154,  167,  171,  159,  164,  157,  165,
       61,  158,   61,   61,  170,  162,   61,   61,  176,  160,
      161,  169,  172,   61,  175,   61,   61,  166,  177,  173,
       61,  167,  171,  180,  164,  183,  165,   61,  174,  189,

       61,  198,   61,  178,  179,   61,  176,  190,  181,  172,
       61,  182,  175,  184,   61,   61,   61,   44,   61,   61,
      193,  180,  183,  191,  197,  174,  189,   61,  194,  198,
      178,  179,   61,   61,  190,  181,   61,  185,  182,  192,
      195,  184,  186,  187,  188,   61,   61,  193,  207,   61,
       61,  191,  197,  204,   45,  199,  194,  201,  214,  196,
      200,  202,  203,   61,  185,  124,  192,  216,  195,  186,
      187,  188,  206,  208,  208,  125,  207,  209,  219,  218,
      204,   61,  199,   61,  201,  214,  196,  200,   61,  202,
      203,  210,  210,   61,  216,  211,  217,  220,   61,   61,

       61,   61,  221,  125,   61,  219,   61,  218,   61,  226,
       61,   61,   61,   61,  228,   61,   61,  222,  223,  225,
      224,  232,  227,   61,  217,  220,  235,   61,   61,  221,
       61,  230,  229,   61,  240,   61,  231,  226,   61,   61,
      233,   61,  228,  234,  222,  223,  225,  224,  236,  232,
      227,  244,   61,  238,  235,  237,   61,  241,  230,  229,
       61,  240,   61,  231,  239,   61,   61,  233,  242,   61,
      234,   61,  243,   61,  246,  245,  236,   61,  249,  244,
       61,  238,  237,  247,  241,  250,   61,   61,  248,   61,
       61,   61,  239,  252,   61,   61,  242,   61,  251,  253,

      243,  254,  246,  245,   61,  255,  249,  256,   61,   61,
       61,  247,  263,  250,  257,  248,  259,   61,  258,   61,
      261,  252,   61,   61,   61,  251,  262,  253,   61,  254,
      260,  265,   61,  255,   61,  256,   61,   61,  268,  263,
      270,  257,   61,  259,  274,  258,  264,  269,  261,   61,
       61,  275,  282,  276,  262,  277,  266,  260,  267,  265,
       61,  271,   61,   61,  273,  280,  268,  270,  283,   61,
      272,   61,  274,  264,  269,  287,  278,   61,  275,  282,
       61,  276,  277,  266,  279,  267,   61,  285,   61,  271,
       61,  273,  286,  280,   61,  284,  283,  272,  289,   61,

       61,  288,  290,  287,  278,   61,   61,   61,   61,   61,
       61,  279,  292,   61,  293,  285,  291,   61,  297,  286,
       61,  301,  284,  296,   61,  294,  289,   61,  288,  295,
      290,   61,  299,   61,  298,  300,   61,   61,   61,  292,
      303,  293,   61,  302,  291,  305,  297,   61,  304,  301,
      306,  296,  294,  307,   61,   61,  295,  308,   61,   61,
      299,  298,  300,  309,   61,   61,  315,  303,   61,   61,
      302,  312,  338,  305,  310,  304,  311,  306,   61,  314,
      307,  313,   61,  317,   61,  308,  316,   61,   61,   61,
      309,  318,   61,   61,  315,  319,  321,  320,  312,  338,

       61,  310,   61,  311,   61,  322,   61,  314,   61,  313,
      317,   61,  323,   61,  316,   61,  327,   61,  329,  318,
      325,   61,  330,  319,  321,  320,  324,  326,  335,  332,
       61,   61,   61,  322,  339,   61,  328,  334,  333,  323,
       61,  331,   61,  336,  327,   61,  329,  325,  337,  330,
      340,   61,  341,  324,  326,  343,  335,  332,   61,   61,
       61,   61,  339,  328,   61,  334,  333,   61,  331,   61,
       61,  336,  346,  347,   61,   61,  337,  342,  340,   61,
      341,   61,   61,  343,  344,  345,  348,   61,  349,   61,
      350,  352,   61,   61,  351,  354,   61,  356,   61,  361,

      346,  347,   61,   61,  342,  355,   61,   61,  357,   61,
      370,  344,  345,  362,  348,  349,  353,  358,  350,  352,
      359,  351,  354,   61,   61,  356,  366,  361,  360,  365,
       61,  363,  355,   61,  369,  357,  364,   61,  370,   61,
      362,   61,   61,   61,  358,  368,   61,  359,   61,  372,
      373,   61,  367,  366,   61,  360,  365,  377,  375,  363,
      378,  369,  371,  374,  364,  381,   61,   61,   61,   61,
       61,   61,   61,  368,   61,   61,  376,  372,  373,  367,
      379,  386,  384,   61,  387,  377,  375,  378,  380,  371,
      374,  382,  381,  388,  383,  385,   61,   61,   61,  391,

       61,   61,   61,  376,   61,   61,  389,  379,  390,  386,
      384,   61,  387,  393,   61,  380,  396,   61,  382,  395,
      388,  383,  385,  394,   61,  397,   61,  391,  392,   61,
      400,   61,   61,  389,  398,   61,  390,   61,  401,  402,
       61,  393,   61,   61,  396,   61,   61,  395,  404,   61,
      394,  406,  397,   61,  405,  392,  399,  403,  400,   61,
       61,  407,  398,   61,  408,  401,  411,  402,  413,   61,
       61,  409,  410,   61,  412,  419,  404,   61,   61,  406,
       61,  405,  415,  399,  403,  414,   61,  416,   61,  407,
       61,  408,  421,  411,   61,  413,  418,  417,  423,  409,

      410,  412,  419,  420,   61,   61,   61,   61,   61,   61,
      415,   61,  414,   61,  416,   61,  422,  431,   61,  424,
      421,   61,  427,  418,  430,  417,  423,  426,  425,  428,
      420,  432,   61,  433,  429,   61,   61,   61,   61,   61,
      438,   61,  442,  422,  437,  431,  424,  435,  436,   61,
      427,  430,   61,  439,  426,  425,  428,  434,   61,  432,
      433,  429,   61,  443,   61,  444,  440,  438,  441,  442,
       61,   61,  437,   61,  445,  435,  436,   61,   61,   61,
       61,  439,   61,   61,  434,   61,   61,   61,   61,   61,
       61,  443,  444,   61,  440,  441,   61,   61,   61,   61,

       61,   61,  445,   38,   38,   38,   38,   38,   43,   43,
       43,   43,   43,   50,   61,   50,   57,   57,   62,   61,
       62,  129,   61,  129,   61,   61,   61,  205,   61,  205,
      205,  213,   61,  213,   61,   61,  212,  211,  211,  209,
      209,  281,  206,   61,   61,   61,   61,   61,   61,   61,
       61,   61,   61,  212,  206,   61,   61,   61,   61,  446,
      121,   61,   55,   52,   47,   46,   42,  446,    5,  446,
      446,  446,  446,  446,  446,  446,  446,  446,  446,  446,
      446,  446,  446,  446,  446,  446,  446,  446,  446,  446,
      446,  446,  446,  446,  446,  446,  446,  446,  446,  446,

      446,  446,  446,  446,  446,  446,  446,  446,  446,  446,
      446,  446,  446,  446,  446,  446,  446,  446,  446,  446,
      446,  446,  446,  446,  446,  446,  446,  446,  446,  446,
      446,  446,  446,  446,  446,  446,  446
    } ;

static yyconst flex_int16_t yy_chk[1338] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    3,    4,
       10,    3,    4,    7,    7,    8,    8,   13,   19,   13,
       15,   15,   17,   37,   20,   17,   21,   41,   41,   13,
       19,   17,   20,  127,   19,  127,  453,   24,   21,   20,

      452,   43,   21,  445,   17,   45,   20,   10,   20,   19,
       21,   37,   26,   17,   58,   23,   24,   13,   19,   17,
       20,   24,   19,   23,   26,  444,   21,   20,   26,   25,
       21,   17,   18,   20,   23,   20,   19,   21,   43,   23,
       25,   58,   23,   24,   45,   59,   18,   29,   24,  443,
       25,   23,   26,   18,   25,   46,   26,   18,   18,   71,
       18,   23,   60,  442,   28,   46,   23,   27,   25,   23,
       29,   29,   28,   59,   18,   27,   78,   25,   71,   27,
       18,   25,   30,   27,   18,   18,   28,   18,   33,   27,
       60,   28,  436,   46,   48,   78,   33,   29,   29,  434,

       28,   30,   34,   27,   48,   71,   30,   27,   63,   31,
       33,   27,   33,   28,  429,   64,   27,   31,   28,   35,
       63,   31,   78,   34,   33,   34,   64,   35,   30,   87,
      427,   31,   48,   30,   49,   31,   49,   33,  426,   33,
       51,   51,   51,   65,   51,   31,   49,  425,   63,   31,
       34,   66,   34,   65,   64,   35,   36,   87,   31,   67,
      132,   72,   31,   32,   36,   68,   69,   73,   36,   72,
       74,   36,   36,   67,   49,   32,   77,   66,   32,   68,
       69,   65,   74,  424,   87,   32,   73,   73,  132,   32,
       32,   68,   36,   80,   73,   76,   36,   72,   77,   36,

       36,   67,   90,   32,   66,   75,   32,   68,   69,   79,
       74,   81,   32,   73,   73,   80,   32,   32,   68,   82,
       76,   73,   83,   76,   75,   77,   86,   85,   90,  421,
       75,   79,   81,   91,   89,   92,   79,  418,   85,   99,
      416,   82,   80,   95,   83,   93,   92,   76,   86,   88,
       76,   75,   85,   85,   91,   90,   94,   75,   79,   81,
       89,   99,   95,   79,   89,   93,   85,   88,   82,   88,
       98,   83,   96,   97,   92,   86,  102,  105,   98,   85,
       85,   91,   94,  100,   97,  101,  106,   89,   99,   95,
      113,   89,   93,  101,   88,  102,   88,  103,   96,  105,

      108,  113,  415,  100,  100,  412,   98,  106,  101,   94,
      411,  101,   97,  103,  112,  107,  410,  122,  104,  109,
      108,  101,  102,  107,  112,   96,  105,  118,  109,  113,
      100,  100,  111,  115,  106,  101,  114,  104,  101,  107,
      111,  103,  104,  104,  104,  116,  133,  108,  120,  139,
      117,  107,  112,  118,  122,  114,  109,  115,  130,  111,
      114,  116,  117,  138,  104,  124,  107,  133,  111,  104,
      104,  104,  120,  123,  123,  124,  120,  123,  139,  138,
      118,  140,  114,  141,  115,  130,  111,  114,  136,  116,
      117,  125,  125,  142,  133,  125,  136,  140,  145,  143,

      144,  146,  141,  124,  148,  139,  149,  138,  151,  146,
      147,  152,  161,  153,  148,  154,  156,  142,  143,  145,
      144,  153,  147,  155,  136,  140,  156,  401,  158,  141,
      399,  151,  149,  397,  161,  165,  152,  146,  162,  157,
      154,  159,  148,  155,  142,  143,  145,  144,  157,  153,
      147,  165,  160,  159,  156,  158,  163,  162,  151,  149,
      164,  161,  174,  152,  160,  166,  168,  154,  163,  173,
      155,  171,  164,  175,  168,  166,  157,  176,  174,  165,
      177,  159,  158,  171,  162,  175,  396,  187,  173,  178,
      179,  182,  160,  177,  180,  181,  163,  183,  176,  178,

      164,  179,  168,  166,  393,  180,  174,  181,  185,  184,
      186,  171,  187,  175,  181,  173,  183,  189,  182,  195,
      185,  177,  192,  190,  199,  176,  186,  178,  194,  179,
      184,  190,  191,  180,  201,  181,  198,  200,  192,  187,
      195,  181,  197,  183,  198,  182,  189,  194,  185,  196,
      204,  199,  214,  200,  186,  201,  191,  184,  191,  190,
      203,  196,  202,  219,  197,  204,  192,  195,  215,  216,
      196,  218,  198,  189,  194,  219,  202,  217,  199,  214,
      220,  200,  201,  191,  203,  191,  225,  217,  226,  196,
      222,  197,  218,  204,  223,  216,  215,  196,  222,  227,

      224,  220,  223,  219,  202,  228,  231,  229,  232,  235,
      238,  203,  225,  236,  226,  217,  224,  233,  231,  218,
      237,  236,  216,  229,  239,  227,  222,  244,  220,  228,
      223,  242,  233,  389,  232,  235,  382,  241,  247,  225,
      238,  226,  245,  237,  224,  241,  231,  250,  239,  236,
      242,  229,  227,  244,  249,  380,  228,  245,  256,  258,
      233,  232,  235,  247,  253,  252,  256,  238,  379,  376,
      237,  250,  282,  241,  249,  239,  249,  242,  257,  253,
      244,  252,  259,  258,  260,  245,  257,  261,  262,  263,
      247,  259,  265,  267,  256,  260,  262,  261,  250,  282,

      266,  249,  273,  249,  269,  263,  268,  253,  272,  252,
      258,  270,  265,  278,  257,  274,  269,  275,  272,  259,
      267,  277,  273,  260,  262,  261,  266,  268,  278,  275,
      276,  279,  280,  263,  283,  285,  270,  277,  276,  265,
      287,  274,  375,  279,  269,  289,  272,  267,  280,  273,
      285,  288,  287,  266,  268,  289,  278,  275,  290,  291,
      293,  294,  283,  270,  371,  277,  276,  296,  274,  304,
      295,  279,  293,  294,  300,  301,  280,  288,  285,  305,
      287,  310,  302,  289,  290,  291,  295,  311,  296,  316,
      300,  302,  317,  314,  301,  304,  326,  310,  313,  316,

      293,  294,  315,  320,  288,  305,  370,  321,  311,  325,
      326,  290,  291,  317,  295,  296,  302,  313,  300,  302,
      314,  301,  304,  318,  319,  310,  321,  316,  315,  320,
      322,  318,  305,  323,  325,  311,  319,  327,  326,  334,
      317,  328,  329,  330,  313,  323,  331,  314,  333,  328,
      329,  332,  322,  321,  335,  315,  320,  333,  331,  318,
      334,  325,  327,  330,  319,  339,  344,  337,  343,  345,
      341,  350,  348,  323,  349,  352,  332,  328,  329,  322,
      335,  348,  344,  355,  349,  333,  331,  334,  337,  327,
      330,  341,  339,  350,  343,  345,  356,  369,  353,  355,

      362,  358,  359,  332,  361,  368,  352,  335,  353,  348,
      344,  360,  349,  358,  366,  337,  361,  367,  341,  360,
      350,  343,  345,  359,  363,  362,  364,  355,  356,  372,
      366,  373,  374,  352,  363,  377,  353,  378,  367,  372,
      387,  358,  384,  400,  361,  365,  390,  360,  374,  383,
      359,  378,  362,  388,  377,  356,  364,  373,  366,  385,
      386,  383,  363,  391,  384,  367,  387,  372,  390,  394,
      392,  385,  386,  357,  388,  400,  374,  402,  398,  378,
      403,  377,  392,  364,  373,  391,  405,  394,  395,  383,
      404,  384,  403,  387,  406,  390,  398,  395,  405,  385,

      386,  388,  400,  402,  407,  417,  408,  422,  413,  419,
      392,  409,  391,  414,  394,  420,  404,  419,  432,  406,
      403,  438,  409,  398,  417,  395,  405,  408,  407,  413,
      402,  420,  423,  422,  414,  431,  430,  428,  354,  440,
      432,  433,  438,  404,  431,  419,  406,  428,  430,  437,
      409,  417,  439,  433,  408,  407,  413,  423,  435,  420,
      422,  414,  441,  439,  351,  440,  435,  432,  437,  438,
      347,  346,  431,  342,  441,  428,  430,  340,  336,  324,
      312,  433,  309,  308,  423,  307,  306,  303,  299,  298,
      297,  439,  440,  292,  435,  437,  286,  284,  271,  264,

      255,  254,  441,  447,  447,  447,  447,  447,  448,  448,
      448,  448,  448,  449,  251,  449,  450,  450,  451,  248,
      451,  454,  246,  454,  455,  243,  455,  456,  240,  456,
      456,  457,  234,  457,  230,  221,  212,  211,  210,  209,
      208,  207,  205,  193,  188,  172,  170,  169,  167,  150,
      137,  135,  134,  126,  119,  110,   84,   70,   62,   50,
       40,   22,   16,   14,   12,   11,    9,    5,  446,  446,
      446,  446,  446,  446,  446,  446,  446,  446,  446,  446,
      446,  446,  446,  446,  446,  446,  446,  446,  446,  446,
      446,  446,  446,  446,  446,  446,  446,  446,  446,  446,

      446,  446,  446,  446,  446,  446,  446,  446,  446,  446,
      446,  446,  446,  446,  446,  446,  446,  446,  446,  446,
      446,  446,  446,  446,  446,  446,  446,  446,  446,  446,
      446,  446,  446,  446,  446,  446,  446
    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "sphinxql.l"
#line 2 "sphinxql.l"
#include "yysphinxql.h"

#if USE_WINDOWS
#pragma warning(push,1)
#endif

// warning, lexer generator dependent!
// this macro relies on that in flex yytext points to the actual location in the buffer
#define YYSTOREBOUNDS \
	{ \
		lvalp->m_iStart = yytext - pParser->m_pBuf; \
		lvalp->m_iEnd = lvalp->m_iStart + yyleng; \
		pParser->m_pLastTokenStart = yytext; \
	}


#line 902 "llsphinxql.c"

#define INITIAL 0
#define ccomment 1

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#if !USE_WINDOWS
#include <unistd.h>
#endif
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    int yy_n_chars;
    int yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    }; /* end struct yyguts_t */

static int yy_init_globals (yyscan_t yyscanner );

int yylex_init (yyscan_t* scanner);

int yylex_init_extra (YY_EXTRA_TYPE user_defined,yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (yyscan_t yyscanner );

int yyget_debug (yyscan_t yyscanner );

void yyset_debug (int debug_flag ,yyscan_t yyscanner );

YY_EXTRA_TYPE yyget_extra (yyscan_t yyscanner );

void yyset_extra (YY_EXTRA_TYPE user_defined ,yyscan_t yyscanner );

FILE *yyget_in (yyscan_t yyscanner );

void yyset_in  (FILE * in_str ,yyscan_t yyscanner );

FILE *yyget_out (yyscan_t yyscanner );

void yyset_out  (FILE * out_str ,yyscan_t yyscanner );

int yyget_leng (yyscan_t yyscanner );

char *yyget_text (yyscan_t yyscanner );

int yyget_lineno (yyscan_t yyscanner );

void yyset_lineno (int line_number ,yyscan_t yyscanner );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (yyscan_t yyscanner );
#else
extern int yywrap (yyscan_t yyscanner );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int ,yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * ,yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (yyscan_t yyscanner );
#else
static int input (yyscan_t yyscanner );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (yyscan_t yyscanner);

#define YY_DECL int yylex (yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

#line 30 "sphinxql.l"


#line 1130 "llsphinxql.c"

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner);
		}

		yy_load_buffer_state(yyscanner );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				yyg->yy_last_accepting_state = yy_current_state;
				yyg->yy_last_accepting_cpos = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 447 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1269 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = yyg->yy_hold_char;
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 32 "sphinxql.l"
{ BEGIN(ccomment); }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 33 "sphinxql.l"
{ }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 34 "sphinxql.l"
{ BEGIN(INITIAL); }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 36 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_AGENT; }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 37 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_AND; }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 38 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_AS; }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 39 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ASC; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 40 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ATTACH; }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 41 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_AVG; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 42 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_BEGIN; }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 43 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_BETWEEN; }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 44 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_BIGINT; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 45 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_BY; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 46 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_CALL; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 47 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_CHARACTER; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 48 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_COLLATION; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 49 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_COMMIT; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 50 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_COMMITTED; }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 51 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_COUNT; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 52 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_CREATE; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 53 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_DELETE; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 54 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_DESC; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 55 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_DESCRIBE; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 56 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_DISTINCT; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 57 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_DIV; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 58 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_DROP; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 59 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_FALSE; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 60 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_FLOAT; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 61 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_FLUSH; }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 62 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_FROM; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 63 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_FUNCTION; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 64 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_GLOBAL; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 65 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_GROUP; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 66 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_GROUPBY; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 67 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_GROUP_CONCAT; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 68 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ID; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 69 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_IN; }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 70 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_INDEX; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 71 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_INSERT; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 72 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_INT; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 73 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_INTO; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 74 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ISOLATION; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 75 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_LEVEL; }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 76 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_LIKE; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 77 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_LIMIT; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 78 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_MATCH; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 79 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_MAX; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 80 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_META; }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 81 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_MIN; }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 82 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_MOD; }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 83 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_NAMES; }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 84 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_NOT; }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 85 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_NULL; }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 86 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_OPTION; }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 87 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_OPTIMIZE; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 88 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_OR; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 89 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ORDER; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 90 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_PLAN; }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 91 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_PROFILE; }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 92 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_RAMCHUNK; }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 93 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_RAND; }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 94 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_READ; }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 95 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_REPEATABLE; }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 96 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_REPLACE; }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 97 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_RETURNS; }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 98 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_ROLLBACK; }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 99 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_RTINDEX; }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 100 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SELECT; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 101 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SERIALIZABLE; }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 102 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SET; }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 103 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SESSION; }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 104 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SHOW; }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 105 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SONAME; }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 106 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_START; }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 107 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_STATUS; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 108 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_STRING; }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 109 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_SUM; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 110 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_TABLES; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 111 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_TO; }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 112 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_TRANSACTION; }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 113 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_TRUE; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 114 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_TRUNCATE; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 115 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_UNCOMMITTED; }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 116 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_UPDATE; }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 117 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_VALUES; }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 118 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_VARIABLES; }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 119 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_WARNINGS; }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 120 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_WEIGHT; }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 121 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_WHERE; }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 122 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_WITHIN; }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 124 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_NE; }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 125 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_NE; }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 126 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_LTE; }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 127 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_GTE; }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 128 "sphinxql.l"
{ YYSTOREBOUNDS; return '='; }
	YY_BREAK
case 96:
/* rule 96 can match eol */
YY_RULE_SETUP
#line 130 "sphinxql.l"
{ YYSTOREBOUNDS; SqlUnescape ( lvalp->m_sValue, yytext, yyleng ); return TOK_QUOTED_STRING; }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 132 "sphinxql.l"
{ YYSTOREBOUNDS; lvalp->m_sValue = yytext; lvalp->m_fValue = (float)strtod ( yytext, NULL ); return TOK_CONST_FLOAT; }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 133 "sphinxql.l"
{ YYSTOREBOUNDS; lvalp->m_sValue = yytext; lvalp->m_fValue = (float)strtod ( yytext, NULL ); return TOK_CONST_FLOAT; }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 134 "sphinxql.l"
{ YYSTOREBOUNDS; lvalp->m_sValue = yytext; lvalp->m_fValue = (float)strtod ( yytext, NULL ); return TOK_CONST_FLOAT; }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 135 "sphinxql.l"
{ YYSTOREBOUNDS; lvalp->m_sValue = yytext; lvalp->m_iValue = (int64_t)strtoull ( yytext, NULL, 10 ); return TOK_CONST_INT; }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 137 "sphinxql.l"
{ YYSTOREBOUNDS; lvalp->m_sValue = yytext; return TOK_ATIDENT; }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 138 "sphinxql.l"
{ YYSTOREBOUNDS; lvalp->m_sValue = yytext; return TOK_ATIDENT; }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 139 "sphinxql.l"
{ YYSTOREBOUNDS; lvalp->m_sValue = yytext; return TOK_ATIDENT; }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 140 "sphinxql.l"
{ YYSTOREBOUNDS; lvalp->m_sValue = yytext; return TOK_IDENT; }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 141 "sphinxql.l"
{ YYSTOREBOUNDS; return TOK_BAD_NUMERIC; }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 142 "sphinxql.l"
{ YYSTOREBOUNDS; lvalp->m_sValue = yytext; return TOK_USERVAR; }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 143 "sphinxql.l"
{ YYSTOREBOUNDS; lvalp->m_sValue = yytext; return TOK_SYSVAR; }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 144 "sphinxql.l"
{ YYSTOREBOUNDS; lvalp->m_iStart++; lvalp->m_iEnd--; lvalp->m_sValue.SetBinary ( yytext+1, strlen(yytext)-2 ); return TOK_ID; }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 145 "sphinxql.l"
{ YYSTOREBOUNDS; lvalp->m_iStart++; lvalp->m_iEnd--; lvalp->m_sValue.SetBinary ( yytext+1, strlen(yytext)-2 ); return TOK_IDENT; }
	YY_BREAK
case 110:
/* rule 110 can match eol */
YY_RULE_SETUP
#line 147 "sphinxql.l"
{ ; }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 148 "sphinxql.l"
{ YYSTOREBOUNDS; return yytext[0]; }
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 150 "sphinxql.l"
ECHO;
	YY_BREAK
#line 1775 "llsphinxql.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(ccomment):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_c_buf_p;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( yywrap(yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = yyg->yytext_ptr;
	register int number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) (yyg->yy_c_buf_p - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2 ,yyscanner );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			yyg->yy_c_buf_p = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  ,yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) (yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size ,yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			yyg->yy_last_accepting_state = yy_current_state;
			yyg->yy_last_accepting_cpos = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 447 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	register int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */
	register char *yy_cp = yyg->yy_c_buf_p;

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		yyg->yy_last_accepting_state = yy_current_state;
		yyg->yy_last_accepting_cpos = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 447 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 446);

	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			int offset = yyg->yy_c_buf_p - yyg->yytext_ptr;
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin ,yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(yyscanner ) )
						return EOF;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner);
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file ,yyscanner);
	yy_load_buffer_state(yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void yy_load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state ) ,yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2 ,yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file ,yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * @param yyscanner The scanner object.
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf ,yyscanner );

	yyfree((void *) b ,yyscanner );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_flush_buffer(b ,yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack(yyscanner);

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void yypop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER ,yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (yyscan_t yyscanner)
{
	int num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyrealloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state ) ,yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b ,yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr , yyscan_t yyscanner)
{
    
	return yy_scan_bytes(yystr,strlen(yystr) ,yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, int  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n ,yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n ,yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg , yyscan_t yyscanner)
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE yyget_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int yyget_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    
        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int yyget_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    
        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
int yyget_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *yyget_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param line_number
 * @param yyscanner The scanner object.
 */
void yyset_lineno (int  line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           yy_fatal_error( "yyset_lineno called with no buffer" , yyscanner); 
    
    yylineno = line_number;
}

/** Set the current column.
 * @param line_number
 * @param yyscanner The scanner object.
 */
void yyset_column (int  column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           yy_fatal_error( "yyset_column called with no buffer" , yyscanner); 
    
    yycolumn = column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = in_str ;
}

void yyset_out (FILE *  out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = out_str ;
}

int yyget_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void yyset_debug (int  bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = bdebug ;
}

/* Accessor methods for yylval and yylloc */

/* User-visible API */

/* yylex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */

int yylex_init(yyscan_t* ptr_yy_globals)

{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* yylex_init_extra has the same functionality as yylex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to yyalloc in
 * the yyextra field.
 */

int yylex_init_extra(YY_EXTRA_TYPE yy_user_defined,yyscan_t* ptr_yy_globals )

{
    struct yyguts_t dummy_yyguts;

    yyset_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }
	
    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), &dummy_yyguts );
	
    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }
    
    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));
    
    yyset_extra (yy_user_defined, *ptr_yy_globals);
    
    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = 0;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = (char *) 0;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER ,yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	yyfree(yyg->yy_buffer_stack ,yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        yyfree(yyg->yy_start_stack ,yyscanner );
        yyg->yy_start_stack = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    yyfree ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n , yyscan_t yyscanner)
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s , yyscan_t yyscanner)
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size , yyscan_t yyscanner)
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size , yyscan_t yyscanner)
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr , yyscan_t yyscanner)
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 150 "sphinxql.l"



// warning, lexer generator dependent!
// flex inserts trailing zero as needed into the buffer when lexing
// but we need that rolled back when doing error reporting from yyerror
void yylex_unhold ( yyscan_t yyscanner )
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( YY_CURRENT_BUFFER )
	{
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
	}
}

#if USE_WINDOWS
#pragma warning(pop)
#endif

